package scripty;

import java.util.*;

public class Program {

    private final String main;
    private final Map<String, Script> scripts = new HashMap<>();

    public Program(String main) {
	this.main = main;
    }

    public String getMain() {
	return main;
    }

    public Set<String> getScriptIds() {
	return Collections.<String>unmodifiableSet(scripts.keySet());
    }

    public Script getScript(String id) {
	if (!scripts.containsKey(id)) {
	    throw new IllegalArgumentException("Unrecognized script id: " + id);
	}
	return scripts.get(id);
    }

    public Script getScript(Script.Run run) {
	if (!scripts.containsKey(run.getId())) {
	    throw new IllegalArgumentException(String.format("Script %s attempted to run unrecognized script %s", run.getScript().getId(), run.getId()));
	}
	Script result = scripts.get(run.getId());
	result.assertValidRun(run);
	return result;
    }

    public Program withScript(String id, Script script) {
	this.scripts.put(id, script);
	return this;
    }
}
